# Errors

- failed to resolve Biofacquim
- failed to resolve ChEBI
- failed to resolve ChEBI
- failed to resolve ChEMBL
- failed to resolve Complex Portal
- failed to resolve HGNC
- failed to resolve IntAct
- failed to resolve InterPro
- failed to resolve Pfam
- failed to resolve Rfam